@@ -27,8 +27,6 @@ using namespace KAsync;
 
 Private::Execution::Execution(const Private::ExecutorBasePtr &executor)
     : executor(executor)
-    , resultBase(nullptr)
-    , tracer(nullptr)
 {
 }
 
@@ -43,38 +41,15 @@ Private::Execution::~Execution()
 
 void Private::Execution::setFinished()
 {
-    delete tracer;
+    tracer.reset();
 }
 
 void Private::Execution::releaseFuture()
 {
-    resultBase = 0;
+    resultBase = nullptr;
 }
 
 
-
-
-Private::ExecutorBase::ExecutorBase(const ExecutorBasePtr &parent)
-    : mPrev(parent)
-{
-}
-
-Private::ExecutorBase::~ExecutorBase()
-{
-}
-
-
-
-
-JobBase::JobBase(const Private::ExecutorBasePtr &executor)
-    : mExecutor(executor)
-{
-}
-
-JobBase::~JobBase()
-{
-}
-
 Job<void> KAsync::doWhile(const Job<ControlFlowFlag> &body)
 {
     return KAsync::start<void>([body] (KAsync::Future<void> &future) {
